@@ -97,7 +97,7 @@ def AnalyzeSpeaker(speaker,form):
         f.write("\t".join(wanted))
         f.write("\n")
         for l in out:
-            f.write("\t".join([ str(l[x]) for x in wanted])
+            f.write("\t".join([ str(l[x]) for x in wanted]))
             f.write("\n")
     logger.info("Completed analysis of %s" % str(speaker))
     return out
